==> fet_5.48.1.orig.tar.bz2: fet-5.48.1/src/interface/constraintsubactivitiespreferredtimeslotsform.h <==
/***************************************************************************
                          constraintsubactivitiespreferredtimeslots.h  -  description
                             -------------------
    begin                : 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTSUBACTIVITIESPREFERREDTIMESLOTSFORM_H
#define CONSTRAINTSUBACTIVITIESPREFERREDTIMESLOTSFORM_H

#include "ui_constraintsubactivitiespreferredtimeslotsform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintSubactivitiesPreferredTimeSlotsForm : public QDialog, Ui::ConstraintSubactivitiesPreferredTimeSlotsForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintSubactivitiesPreferredTimeSlotsForm(QWidget* parent);
	~ConstraintSubactivitiesPreferredTimeSlotsForm();

	bool filterOk(TimeConstraint* ctr);
	
public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();
	
	void filterChanged();
	
	void help();
};

#endif

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/constraintsubactivitiespreferredtimeslotsform.h <==
/***************************************************************************
                          constraintsubactivitiespreferredtimeslots.h  -  description
                             -------------------
    begin                : 2008
    copyright            : (C) 2008 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTSUBACTIVITIESPREFERREDTIMESLOTSFORM_H
#define CONSTRAINTSUBACTIVITIESPREFERREDTIMESLOTSFORM_H

#include "ui_constraintsubactivitiespreferredtimeslotsform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintSubactivitiesPreferredTimeSlotsForm : public QDialog, Ui::ConstraintSubactivitiesPreferredTimeSlotsForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintSubactivitiesPreferredTimeSlotsForm(QWidget* parent);
	~ConstraintSubactivitiesPreferredTimeSlotsForm();

	bool filterOk(TimeConstraint* ctr);
	
public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();
	
	void filterChanged();
	
	void help();
};

#endif
